# Data Visualization Curriculum

A data visualization curriculum of interactive notebooks, using [Vega-Lite](https://vega.github.io/vega-lite/) and [Altair](https://altair-viz.github.io/). This repository contains a series of **Python**-based Jupyter notebooks. The notebooks are online in a [Jupyter book](https://uwdata.github.io/visualization-curriculum/intro.html), runnable locally or online on [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum) or [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum). A corresponding set of **JavaScript** notebooks are available online on [Observable](https://observablehq.com/@uwdata/data-visualization-curriculum).

## Curriculum

### Table of Contents

1. Introduction to Vega-Lite / Altair<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_introduction.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_introduction.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_introduction.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_introduction.ipynb) |
     [Observable](https://observablehq.com/@uwdata/introduction-to-vega-lite)
   </small>

2. Data Types, Graphical Marks, and Visual Encoding Channels<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_marks_encoding.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_marks_encoding.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_marks_encoding.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_marks_encoding.ipynb) |
     [Observable](https://observablehq.com/@uwdata/data-types-graphical-marks-and-visual-encoding-channels)
   </small>

3. Data Transformation<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_data_transformation.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_data_transformation.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_data_transformation.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_data_transformation.ipynb) |
     [Observable](https://observablehq.com/@uwdata/data-transformation)
   </small>

4. Scales, Axes, and Legends<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_scales_axes_legends.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_scales_axes_legends.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_scales_axes_legends.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_scales_axes_legends.ipynb) |
     [Observable](https://observablehq.com/@uwdata/scales-axes-and-legends)
   </small>

5. Multi-View Composition<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_view_composition.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_view_composition.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_view_composition.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_view_composition.ipynb) |
     [Observable](https://observablehq.com/@uwdata/multi-view-composition)
   </small>

6. Interaction<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_interaction.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_interaction.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_interaction.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_interaction.ipynb) |
     [Observable](https://observablehq.com/@uwdata/interaction)
   </small>

7. Cartographic Visualization<br/>
   <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_cartographic.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_cartographic.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_cartographic.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_cartographic.ipynb) |
     [Observable](https://observablehq.com/@uwdata/cartographic-visualization)
   </small>

### Support

- Altair Debugging Guide<br/>
  <small>
     [Jupyter Book](https://uwdata.github.io/visualization-curriculum/altair_debugging.html) |
     [Jupyter](https://github.com/uwdata/visualization-curriculum/blob/master/altair_debugging.ipynb) |
     [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/blob/master/altair_debugging.ipynb) |
     [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/blob/master/altair_debugging.ipynb)
  </small>

## Getting Started

The visualization curriculum can be used either online or on your local computer.

### Online

- [Jupyter Book](https://uwdata.github.io/visualization-curriculum/) to read Python notebooks online.
- Run the **Python** notebooks online on [Colab](https://colab.research.google.com/github/uwdata/visualization-curriculum/) or [Nextjournal](https://github.nextjournal.com/uwdata/visualization-curriculum/)
- Run the **JavaScript** notebooks online using [Observable](https://observablehq.com/collection/@uwdata/visualization-curriculum)

### Local Installation

1. [Install Altair and a notebook environment](https://altair-viz.github.io/getting_started/installation.html). The most recent versions of these notebooks use _Altair version 4_.
2. Download the notebooks from the [releases page](https://github.com/uwdata/visualization-curriculum/releases). Typically you will want to use the most recent release.  (If you wish to use notebooks for Altair version 3, download the [Altair v3.2 release](https://github.com/uwdata/visualization-curriculum/releases/tag/altair-v3).)
3. Open the notebooks in your local notebook environment. For example, if you have JupyterLab installed (v1.0 or higher is required), run `jupyter lab` within the directory containing the notebooks.

Depending on your programming environment (and whether or not you have a live internet connection), you may want to specify a particular [renderer](https://altair-viz.github.io/user_guide/display_frontends.html) for Altair.

## Credits

Developed at the University of Washington by Jeffrey Heer, Dominik Moritz, Jake VanderPlas, and Brock Craft. Thanks to the [UW Interactive Data Lab](https://idl.cs.washington.edu/) and Arvind Satyanarayan for their valuable input and feedback! Thanks also to the students of [UW CSE512 Spring 2019](https://courses.cs.washington.edu/courses/cse512/19sp/), the first group to use these notebooks within an integrated course curriculum.
